#
# spec file for package xload
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xload
Version:        1.2.0
Release:        1.5
Summary:        X utility to display system load average
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        xload.desktop
Source2:        xload.png
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xt)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
xload displays a periodically updating histogram of the system load
average.

%prep
%setup -q
cp %{SOURCE1} .

%build
%configure
%make_build

%install
%make_install
%suse_update_desktop_file -i -u xload System Monitor
install -m0644 -D %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/xload.png

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xload
%{_datadir}/applications/xload.desktop
%{_datadir}/pixmaps/xload.png
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/XLoad
%{_mandir}/man1/xload.1%{?ext_man}

%changelog
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * Use imdent to realign remaining pre-processer directives
  * Use autoconf to check for <protocols/rwhod.h> instead of
    OS-specific ifdefs
  * configure: Use AC_SYS_LARGEFILE to enable large file
    support
  * Handle files whose sizes, inode numbers, or timestamps
    may be out of range of the original 32-bit APIs
  * Use asprintf() if available
  * Add -help and -version options
  * Print which arguments were unknown before giving usage
    message
* Mon Apr  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.4
  * This release ends support for SGI Irix, which SGI themselves
    did in 2013.
* Fri Dec  3 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Wed Apr  4 2018 sndirsch@suse.com
- Update to version 1.1.3
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * autogen.sh: use quoted string variables
  * Use Windows load interface for Win32 build, as well as Cygwin
  * Don't try to use [gs]et[ug]id on Win32
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
  * Use wrapped windows header to fix compilation for Cygwin
* Sat Aug 17 2013 zaitor@opensuse.org
- Update to version 1.1.2:
  + Add noreturn attribute to usage() as suggested
    by -Wmissing-noreturn.
  + Use C99 struct initializers for XKeyboardControl values.
  + Use 'imdent' to make the deeply nested #ifdef levels easier to
    follow.
  + Cleanup trailing whitespace.
  + Make getloadavg() the first choice on Unix systems that have
    it.
  + unifdef: -UX_NOT_POSIX, -U__UNIXOS2__ , -Usequent, -Uhcx,
  - UUTEK, -Ualliant, -Usony, -Uumips, -UMOTOROLA, -UAIXV3,
  - UCRAY.
  + Combine usage message strings.
  + Eliminate use of tab stops.  Helps with translation to DocBook.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.1.1:
  + Solaris: use getloadavg from libc instead of kstats.
  + Solaris: Read avenrun_1min kstat as a uint32, not a long.
  + Remove DG/UX support.
  + Build system fixes.
- Add pkgconfig(xproto) BuildRequires: new dependency.
* Fri Apr 13 2012 mgorse@opensuse.org
- Split xload from xorg-x11. Initial version: 1.1.0.
